Pipelines
=========

.. _reconstruction_pipelines:

Reconstruction
--------------

.. _sirt_pipeline:

.. autofunction:: mumott.pipelines.reconstruction.run_sirt

.. autofunction:: mumott.pipelines.reconstruction.run_sigtt

.. _alignment_pipelines:

Alignment
---------

.. autofunction:: mumott.pipelines.alignment.run_cross_correlation_alignment

.. autofunction:: mumott.pipelines.alignment.shift_center_of_reconstruction
